/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_obRXIvIy);
  numBytes += sPhasor_k_init(&sPhasor_VUgGLFhL, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_GakpXiQV);
  numBytes += sRPole_init(&sRPole_Yz6UrVZ6);
  numBytes += sRPole_init(&sRPole_MOXtzb40);
  numBytes += sTabhead_init(&sTabhead_ImpfAu75, &hTable_asvQ22Ym);
  numBytes += sTabread_init(&sTabread_fSsQAbPh, &hTable_asvQ22Ym, false);
  numBytes += sTabread_init(&sTabread_0ZaopHaa, &hTable_asvQ22Ym, false);
  numBytes += sLine_init(&sLine_MQiidacp);
  numBytes += sTabhead_init(&sTabhead_eOel71QU, &hTable_8QaqHuwN);
  numBytes += sTabread_init(&sTabread_x4kdrwFM, &hTable_8QaqHuwN, false);
  numBytes += sTabread_init(&sTabread_Hn5IF5ae, &hTable_8QaqHuwN, false);
  numBytes += sLine_init(&sLine_GZkqdnPI);
  numBytes += sTabwrite_init(&sTabwrite_6PIN5yuq, &hTable_8QaqHuwN);
  numBytes += sTabwrite_init(&sTabwrite_8nrTCxz4, &hTable_asvQ22Ym);
  numBytes += cVar_init_f(&cVar_bZmQkEmu, 0.0f);
  numBytes += cVar_init_f(&cVar_W6CzZ1rh, 0.0f);
  numBytes += cVar_init_f(&cVar_dowWwfMR, 0.0f);
  numBytes += cVar_init_f(&cVar_2dmzMtyX, 0.0f);
  numBytes += cVar_init_s(&cVar_C4eVnhrY, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_1avnzvzd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zzuzq48z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_afREebVY, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_MyjMvgr0, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_lZzKW3Vq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nAbhwuI4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pePzX3K2, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_z2kWljN8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_znARK7BR, 0.0f);
  numBytes += hTable_init(&hTable_8QaqHuwN, 256);
  numBytes += cDelay_init(this, &cDelay_63CfoJGP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ILMPuFPO, 0.0f);
  numBytes += hTable_init(&hTable_asvQ22Ym, 256);
  numBytes += cVar_init_f(&cVar_RIl38UMk, 14.0f);
  numBytes += cBinop_init(&cBinop_SdnIF2rj, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fSh67LyR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l15W7iu9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IxHBqBn9, 14.0f);
  numBytes += cBinop_init(&cBinop_57sENJqe, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_72v0jby7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0ZOBjRRw, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_iuKVl4L0, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_zP1ErcNA, 1, -1);
  numBytes += cVar_init_f(&cVar_xMD2fK63, 0.2f);
  numBytes += cSlice_init(&cSlice_9UlJTQ5T, 1, -1);
  numBytes += cVar_init_f(&cVar_Czu8KRgQ, 0.0f);
  numBytes += cSlice_init(&cSlice_yjesPBqt, 1, -1);
  numBytes += cVar_init_f(&cVar_mFajEewf, 2.0f);
  numBytes += cSlice_init(&cSlice_gdEksgSh, 1, -1);
  numBytes += cVar_init_f(&cVar_7Qi6r3Ua, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_8QaqHuwN);
  hTable_free(&hTable_asvQ22Ym);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_8QaqHuwN; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_asvQ22Ym; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xk73MTTB_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1VRGxZG8_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dMRdoobg_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TK5GKYY8_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RoGmEO9q_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hG1L4o0N_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Fe7umsHy_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Hp5iIlnc_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hMsRkBUj_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_bZmQkEmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PfqF476l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_W6CzZ1rh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1qingYbh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_dowWwfMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fiphHNf0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_2dmzMtyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_llhavBy2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_3cn4K6Qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QciAvglH_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QciAvglH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_VUgGLFhL, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_LJSjcSBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oZWp2gSr_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_oZWp2gSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wsNro6Ui_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_C4eVnhrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CsJmxhFs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_8rVLk7gQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lUaQqx3A_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1avnzvzd, m);
}

void Heavy_WSTD_FLANGR::cBinop_wsNro6Ui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zzuzq48z, m);
}

void Heavy_WSTD_FLANGR::cMsg_CsJmxhFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8rVLk7gQ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_lUaQqx3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_afREebVY, m);
}

void Heavy_WSTD_FLANGR::cMsg_Rm49EZ43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cWZAk7MD_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_cWZAk7MD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LXnA9cbw_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_MyjMvgr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dx4sCbWd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_8lE7sLZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bvQrUL0z_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lZzKW3Vq, m);
}

void Heavy_WSTD_FLANGR::cBinop_LXnA9cbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nAbhwuI4, m);
}

void Heavy_WSTD_FLANGR::cMsg_Dx4sCbWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8lE7sLZL_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_bvQrUL0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pePzX3K2, m);
}

void Heavy_WSTD_FLANGR::cBinop_HwrOPwCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_s5zvIzBS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_s5zvIzBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_OEd7PRDp_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_5Ih1DErj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hi1ZBIk5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_XtDwZ1lI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lk5pdW51_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_OEd7PRDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rXZeS3Dq_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_rXZeS3Dq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mbld4YMr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ecZxv9Gz_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_ecZxv9Gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JJDKgVfJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_Mbld4YMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_in5vq7CU_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_in5vq7CU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lLrmBQYH_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_JJDKgVfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SEbbNNHO_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_SEbbNNHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_za5KVPe6_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_lLrmBQYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_5Ih1DErj_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_za5KVPe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_XtDwZ1lI_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_KHkPHAcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rfsQe5hj_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_rfsQe5hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BHP3oSGd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_rG0RdL9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tvryusW3_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_tvryusW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1EUU8xWo_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_z2kWljN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_z2kWljN8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_znARK7BR, 0, m, &cDelay_znARK7BR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z2kWljN8, 0, m, &cDelay_z2kWljN8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6PIN5yuq, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_znARK7BR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_znARK7BR, m);
  cMsg_thGfR7qr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_VbfjSXhh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_gfBLsvZ7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_gWqNna2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OXlCkSn4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_8QaqHuwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3GL0dwmx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z2kWljN8, 2, m, &cDelay_z2kWljN8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CSt6FlnT_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_OXlCkSn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8QaqHuwN, 0, m, &hTable_8QaqHuwN_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_1EUU8xWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_gWqNna2Y_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_thGfR7qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8QaqHuwN, 0, m, &hTable_8QaqHuwN_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_CSt6FlnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_z2kWljN8, 0, m, &cDelay_z2kWljN8_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_3GL0dwmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_znARK7BR, 2, m, &cDelay_znARK7BR_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_gfBLsvZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6PIN5yuq, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_pf5i5Elt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0aCJLHrv_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_0aCJLHrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kvEoaAhb_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_63CfoJGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_63CfoJGP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ILMPuFPO, 0, m, &cDelay_ILMPuFPO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_63CfoJGP, 0, m, &cDelay_63CfoJGP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8nrTCxz4, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_ILMPuFPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ILMPuFPO, m);
  cMsg_DIw52As3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_vjhneXPZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_BZMfUDQV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_zKOboe2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YEdVOsA7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_asvQ22Ym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xzdKVaBF_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_63CfoJGP, 2, m, &cDelay_63CfoJGP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8yyKBGsd_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_YEdVOsA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_asvQ22Ym, 0, m, &hTable_asvQ22Ym_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_kvEoaAhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_zKOboe2z_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_DIw52As3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_asvQ22Ym, 0, m, &hTable_asvQ22Ym_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_8yyKBGsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_63CfoJGP, 0, m, &cDelay_63CfoJGP_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_xzdKVaBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ILMPuFPO, 2, m, &cDelay_ILMPuFPO_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_BZMfUDQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8nrTCxz4, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_RIl38UMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdnIF2rj, HV_BINOP_MULTIPLY, 0, m, &cBinop_SdnIF2rj_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_jkqHuVhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yu4sOUZn_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_yu4sOUZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M4ghFRII_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_SdnIF2rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_biC7DgMO_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_xFoflVfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SdnIF2rj, HV_BINOP_MULTIPLY, 1, m, &cBinop_SdnIF2rj_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_M4ghFRII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xFoflVfY_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_biC7DgMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zYh16OoA_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_zYh16OoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vRhYFvAs_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_l15W7iu9, m);
}

void Heavy_WSTD_FLANGR::cBinop_vRhYFvAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fSh67LyR, m);
}

void Heavy_WSTD_FLANGR::cVar_IxHBqBn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_57sENJqe, HV_BINOP_MULTIPLY, 0, m, &cBinop_57sENJqe_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_YOaC6OS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wUFeByvm_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_wUFeByvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A6DG7cva_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_57sENJqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_nk7lXAOI_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_H7hZlM9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_57sENJqe, HV_BINOP_MULTIPLY, 1, m, &cBinop_57sENJqe_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_A6DG7cva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_H7hZlM9v_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_nk7lXAOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_2vgwaHog_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_2vgwaHog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_L01tqfNa_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0ZOBjRRw, m);
}

void Heavy_WSTD_FLANGR::cBinop_L01tqfNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_72v0jby7, m);
}

void Heavy_WSTD_FLANGR::cMsg_BHP3oSGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GakpXiQV, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_C4yzWZ1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_RYLiBNoi_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_k5xBbV1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_C4yzWZ1j_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_MFQpZMKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QVprCwTL_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_W9VucwM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_atpmXyks_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_atpmXyks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iuKVl4L0, HV_BINOP_MULTIPLY, 1, m, &cBinop_iuKVl4L0_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_QVprCwTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_W9VucwM8_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_iuKVl4L0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4tlG2y5e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_RYLiBNoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iuKVl4L0, HV_BINOP_MULTIPLY, 0, m, &cBinop_iuKVl4L0_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_4tlG2y5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GZkqdnPI, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_rqG55OM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_zXPOPoap_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_zXPOPoap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MFQpZMKl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k5xBbV1q_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_Qn99JqZC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zP1ErcNA, 0, m, &cSlice_zP1ErcNA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PpBGE5TS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_zP1ErcNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NY9RgmVf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NY9RgmVf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_xMD2fK63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NY9RgmVf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_NY9RgmVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hG1L4o0N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_PpBGE5TS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9UlJTQ5T, 0, m, &cSlice_9UlJTQ5T_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oG9lkoNz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_9UlJTQ5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qK0F34iz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qK0F34iz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_Czu8KRgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qK0F34iz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_qK0F34iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RoGmEO9q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_oG9lkoNz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yjesPBqt, 0, m, &cSlice_yjesPBqt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dJg5OPEi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_yjesPBqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JUGrlaOy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JUGrlaOy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_mFajEewf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JUGrlaOy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_JUGrlaOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Hp5iIlnc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_dJg5OPEi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gdEksgSh, 0, m, &cSlice_gdEksgSh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_gdEksgSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EUQg2DyL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EUQg2DyL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_7Qi6r3Ua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EUQg2DyL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_EUQg2DyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Fe7umsHy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_hi1ZBIk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MQiidacp, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Lk5pdW51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_obRXIvIy, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_llhavBy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Qn99JqZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_PfqF476l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Qn99JqZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_1qingYbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Qn99JqZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_fiphHNf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Qn99JqZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_MLDAwsbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2dmzMtyX, 0, m, &cVar_2dmzMtyX_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_lXIVLi4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bZmQkEmu, 0, m, &cVar_bZmQkEmu_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_9wQgiTYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dowWwfMR, 0, m, &cVar_dowWwfMR_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_Hp5iIlnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_3cn4K6Qa_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_RoGmEO9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rqG55OM3_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_hMsRkBUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jkqHuVhK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RIl38UMk, 0, m, &cVar_RIl38UMk_sendMessage);
  cMsg_YOaC6OS0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IxHBqBn9, 0, m, &cVar_IxHBqBn9_sendMessage);
  cMsg_rG0RdL9P_sendMessage(_c, 0, m);
  cMsg_pf5i5Elt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xMD2fK63, 0, m, &cVar_xMD2fK63_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Czu8KRgQ, 0, m, &cVar_Czu8KRgQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mFajEewf, 0, m, &cVar_mFajEewf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7Qi6r3Ua, 0, m, &cVar_7Qi6r3Ua_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C4eVnhrY, 0, m, &cVar_C4eVnhrY_sendMessage);
  cMsg_LJSjcSBz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MyjMvgr0, 0, m, &cVar_MyjMvgr0_sendMessage);
  cMsg_Rm49EZ43_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_Fe7umsHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_HwrOPwCl_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_hG1L4o0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KHkPHAcL_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_TK5GKYY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W6CzZ1rh, 0, m, &cVar_W6CzZ1rh_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_dMRdoobg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_MLDAwsbT_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_1VRGxZG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_9wQgiTYG_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_xk73MTTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_lXIVLi4m_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_obRXIvIy, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_VUgGLFhL, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_GakpXiQV, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_l15W7iu9, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_fSh67LyR, VOf(Bf3));
    __hv_rpole_f(&sRPole_Yz6UrVZ6, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_0ZOBjRRw, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_72v0jby7, VOf(Bf4));
    __hv_rpole_f(&sRPole_MOXtzb40, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_ImpfAu75, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Zzuzq48z, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_afREebVY, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_1avnzvzd, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_fSsQAbPh, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_0ZaopHaa, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_MQiidacp, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_eOel71QU, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_nAbhwuI4, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_pePzX3K2, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_lZzKW3Vq, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_x4kdrwFM, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_Hn5IF5ae, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_GZkqdnPI, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_6PIN5yuq, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_8nrTCxz4, VIf(Bf0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
