/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvSignalTabread.h"
#include "HvSignalLine.h"
#include "HvSignalRPole.h"
#include "HvControlDelay.h"
#include "HvControlCast.h"
#include "HvSignalTabwrite.h"
#include "HvSignalPhasor.h"
#include "HvControlUnop.h"
#include "HvControlSlice.h"
#include "HvSignalDel1.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvTable.h"
#include "HvMath.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_bZmQkEmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_W6CzZ1rh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dowWwfMR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2dmzMtyX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3cn4K6Qa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QciAvglH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LJSjcSBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oZWp2gSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C4eVnhrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8rVLk7gQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wsNro6Ui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CsJmxhFs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lUaQqx3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rm49EZ43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cWZAk7MD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MyjMvgr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8lE7sLZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LXnA9cbw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dx4sCbWd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bvQrUL0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HwrOPwCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s5zvIzBS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5Ih1DErj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_XtDwZ1lI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OEd7PRDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rXZeS3Dq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ecZxv9Gz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mbld4YMr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_in5vq7CU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JJDKgVfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SEbbNNHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLrmBQYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_za5KVPe6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KHkPHAcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rfsQe5hj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rG0RdL9P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tvryusW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_z2kWljN8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_znARK7BR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VbfjSXhh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_gWqNna2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_8QaqHuwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OXlCkSn4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1EUU8xWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_thGfR7qr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CSt6FlnT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3GL0dwmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gfBLsvZ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pf5i5Elt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0aCJLHrv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_63CfoJGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ILMPuFPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vjhneXPZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_zKOboe2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_asvQ22Ym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YEdVOsA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kvEoaAhb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DIw52As3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8yyKBGsd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xzdKVaBF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BZMfUDQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RIl38UMk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jkqHuVhK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yu4sOUZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SdnIF2rj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFoflVfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M4ghFRII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_biC7DgMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zYh16OoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vRhYFvAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IxHBqBn9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YOaC6OS0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wUFeByvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_57sENJqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H7hZlM9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A6DG7cva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nk7lXAOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2vgwaHog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L01tqfNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BHP3oSGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_C4yzWZ1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k5xBbV1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MFQpZMKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W9VucwM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_atpmXyks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QVprCwTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iuKVl4L0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RYLiBNoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4tlG2y5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rqG55OM3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zXPOPoap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Qn99JqZC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zP1ErcNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xMD2fK63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NY9RgmVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PpBGE5TS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9UlJTQ5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Czu8KRgQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qK0F34iz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oG9lkoNz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yjesPBqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mFajEewf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JUGrlaOy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dJg5OPEi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_gdEksgSh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7Qi6r3Ua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EUQg2DyL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hi1ZBIk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lk5pdW51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_llhavBy2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PfqF476l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1qingYbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fiphHNf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MLDAwsbT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lXIVLi4m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9wQgiTYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Hp5iIlnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RoGmEO9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hMsRkBUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Fe7umsHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hG1L4o0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TK5GKYY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dMRdoobg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1VRGxZG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xk73MTTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_obRXIvIy;
  SignalPhasor sPhasor_VUgGLFhL;
  SignalLine sLine_GakpXiQV;
  SignalRPole sRPole_Yz6UrVZ6;
  SignalRPole sRPole_MOXtzb40;
  SignalTabhead sTabhead_ImpfAu75;
  SignalTabread sTabread_fSsQAbPh;
  SignalTabread sTabread_0ZaopHaa;
  SignalLine sLine_MQiidacp;
  SignalTabhead sTabhead_eOel71QU;
  SignalTabread sTabread_x4kdrwFM;
  SignalTabread sTabread_Hn5IF5ae;
  SignalLine sLine_GZkqdnPI;
  SignalTabwrite sTabwrite_6PIN5yuq;
  SignalTabwrite sTabwrite_8nrTCxz4;
  ControlVar cVar_bZmQkEmu;
  ControlVar cVar_W6CzZ1rh;
  ControlVar cVar_dowWwfMR;
  ControlVar cVar_2dmzMtyX;
  ControlBinop cBinop_3cn4K6Qa;
  ControlBinop cBinop_QciAvglH;
  ControlVar cVar_C4eVnhrY;
  ControlBinop cBinop_wsNro6Ui;
  ControlBinop cBinop_lUaQqx3A;
  SignalVarf sVarf_1avnzvzd;
  SignalVarf sVarf_Zzuzq48z;
  SignalVarf sVarf_afREebVY;
  ControlVar cVar_MyjMvgr0;
  ControlBinop cBinop_LXnA9cbw;
  ControlBinop cBinop_bvQrUL0z;
  SignalVarf sVarf_lZzKW3Vq;
  SignalVarf sVarf_nAbhwuI4;
  SignalVarf sVarf_pePzX3K2;
  ControlBinop cBinop_HwrOPwCl;
  ControlBinop cBinop_s5zvIzBS;
  ControlBinop cBinop_OEd7PRDp;
  ControlBinop cBinop_rXZeS3Dq;
  ControlBinop cBinop_in5vq7CU;
  ControlBinop cBinop_SEbbNNHO;
  ControlBinop cBinop_lLrmBQYH;
  ControlBinop cBinop_za5KVPe6;
  ControlBinop cBinop_KHkPHAcL;
  ControlBinop cBinop_rfsQe5hj;
  ControlDelay cDelay_z2kWljN8;
  ControlDelay cDelay_znARK7BR;
  ControlBinop cBinop_gWqNna2Y;
  HvTable hTable_8QaqHuwN;
  ControlBinop cBinop_1EUU8xWo;
  ControlDelay cDelay_63CfoJGP;
  ControlDelay cDelay_ILMPuFPO;
  ControlBinop cBinop_zKOboe2z;
  HvTable hTable_asvQ22Ym;
  ControlBinop cBinop_kvEoaAhb;
  ControlVar cVar_RIl38UMk;
  ControlBinop cBinop_SdnIF2rj;
  ControlBinop cBinop_xFoflVfY;
  SignalVarf sVarf_fSh67LyR;
  ControlBinop cBinop_biC7DgMO;
  ControlBinop cBinop_zYh16OoA;
  ControlBinop cBinop_vRhYFvAs;
  SignalVarf sVarf_l15W7iu9;
  ControlVar cVar_IxHBqBn9;
  ControlBinop cBinop_57sENJqe;
  ControlBinop cBinop_H7hZlM9v;
  SignalVarf sVarf_72v0jby7;
  ControlBinop cBinop_nk7lXAOI;
  ControlBinop cBinop_2vgwaHog;
  ControlBinop cBinop_L01tqfNa;
  SignalVarf sVarf_0ZOBjRRw;
  ControlBinop cBinop_W9VucwM8;
  ControlBinop cBinop_atpmXyks;
  ControlBinop cBinop_QVprCwTL;
  ControlBinop cBinop_iuKVl4L0;
  ControlBinop cBinop_RYLiBNoi;
  ControlBinop cBinop_rqG55OM3;
  ControlBinop cBinop_zXPOPoap;
  ControlSlice cSlice_zP1ErcNA;
  ControlVar cVar_xMD2fK63;
  ControlSlice cSlice_9UlJTQ5T;
  ControlVar cVar_Czu8KRgQ;
  ControlSlice cSlice_yjesPBqt;
  ControlVar cVar_mFajEewf;
  ControlSlice cSlice_gdEksgSh;
  ControlVar cVar_7Qi6r3Ua;
  ControlBinop cBinop_MLDAwsbT;
  ControlBinop cBinop_lXIVLi4m;
  ControlBinop cBinop_9wQgiTYG;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
